@@ -3,7 +3,8 @@ from collections import namedtuple
         
 status_fields = ('present num_modified num_untracked to_push simple_push '
                 'to_merge simple_merge branch current_branch branch_mismatch '
-                'local_branch_exists remote_branch_exists url current_url track').split()
+                'local_branch_exists remote_branch_exists url current_url track '
+                'is_git_repo has_remote').split()
 StatusResult = namedtuple('StatusResult', status_fields)
 
 __all__ = ['StatusResult', 'status_fields', 'status2string']
@@ -26,7 +27,16 @@ def status2string(r, res):
     remarks = []
     
     if not res.present:
-        flags[flag_modified] = 'missing'
+        flags[flag_modified] = '!'
+        remarks.append('Dir does not exists')
+    elif not res.is_git_repo:
+        flags[flag_modified] = '!'
+        remarks.append('Dir exists but no git repo found.'
+                       ' (Fix with "git init".)')
+    elif not res.has_remote:
+        flags[flag_branch_remote] = '!'
+        remarks.append('No remote configured.'
+                       ' (Fix with "git remote add origin %s".)' % r.url)
     else:    
         if res.num_modified or res.num_untracked:
             fm = '%3dm' % res.num_modified if res.num_modified else "    "
@@ -44,7 +54,11 @@ def status2string(r, res):
 
         # print('%s < %s' % (res.branch, res.track))
         if res.track == None:
-            remarks.append('No upstream configured.')
+            if res.remote_branch_exists:
+                remarks.append('No upstream configured.'
+                               ' (Should be fixable by "pat fix-upstream".)')
+            else:
+                remarks.append('No upstream configured and no remote branch.')
             flags[flag_branch_remote] = '!R'
 
         if  res.local_branch_exists == False:
@@ -52,14 +66,14 @@ def status2string(r, res):
             flags[flag_branch_local] = '!L'
             
             remarks.append('Local branch %r does not exist.' % res.branch +
-                           ' (Should be fixable by "make-branch".)')
+                           ' (Should be fixable by "pat make-branch".)')
         
         if  res.remote_branch_exists == False:
             flags[flag_branch_remote] = 'no remote %s' % res.branch
             flags[flag_branch_remote] = '!R' 
             
             remarks.append('Remote branch %r does not exist.' % res.branch +
-                           ' (Should be fixable by "push".)')
+                           ' (Should be fixable by "pat push".)')
 
         
         if res.branch_mismatch == True:
